@@ -1,11 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Pino Toscano <pino@kde.org>                     *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Pino Toscano <pino@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _OKULAR_FORM_H_
 #define _OKULAR_FORM_H_
@@ -162,7 +159,7 @@ public:
 
 protected:
     /// @cond PRIVATE
-    FormField(FormFieldPrivate &dd);
+    explicit FormField(FormFieldPrivate &dd);
     Q_DECLARE_PRIVATE(FormField)
     FormFieldPrivate *d_ptr;
     /// @endcond
