@@ -50,7 +50,7 @@
 class PickPointEngine : public AnnotatorEngine
 {
 public:
-    PickPointEngine(const QDomElement &engineElement)
+    explicit PickPointEngine(const QDomElement &engineElement)
         : AnnotatorEngine(engineElement)
         , clicked(false)
         , xscale(1.0)
@@ -70,7 +70,7 @@ public:
 
         // create engine objects
         if (!hoverIconName.simplified().isEmpty())
-            pixmap = GuiUtils::loadStamp(hoverIconName, size);
+            pixmap = Okular::AnnotationUtils::loadStamp(hoverIconName, size);
     }
 
     QRect event(EventType type, Button button, Modifiers modifiers, double nX, double nY, double xScale, double yScale, const Okular::Page *page) override
@@ -320,6 +320,7 @@ public:
         , m_page(nullptr)
         , m_pageView(pageView)
         , m_startOver(false)
+        , m_aborted(false)
     {
         m_block = true;
     }
@@ -356,8 +357,8 @@ public:
         const Okular::CertificateStore *certStore = m_document->certificateStore();
         bool userCancelled;
         const QList<Okular::CertificateInfo *> &certs = certStore->signingCertificates(&userCancelled);
-
         if (userCancelled) {
+            m_aborted = true;
             return {};
         }
 
@@ -403,6 +404,7 @@ public:
                 if (ok) {
                     passok = cert->checkPassword(passToUse);
                 } else {
+                    passok = false;
                     break;
                 }
             }
@@ -411,9 +413,12 @@ public:
                 certCommonName = cert->subjectInfo(Okular::CertificateInfo::CommonName);
             } else {
                 certNicknameToUse.clear();
+                m_aborted = true;
             }
         } else {
+            // The Cancel button has been clicked in the certificate dialog.
             certNicknameToUse.clear();
+            m_aborted = true;
         }
 
         m_creationCompleted = false;
@@ -426,7 +431,7 @@ public:
 
     bool isAccepted() const
     {
-        return !certNicknameToUse.isEmpty();
+        return !m_aborted && !certNicknameToUse.isEmpty();
     }
 
     bool userWantsToStartOver() const
@@ -434,6 +439,11 @@ public:
         return m_startOver;
     }
 
+    bool isAborted() const
+    {
+        return m_aborted;
+    }
+
     bool sign(const QString &newFilePath)
     {
         Okular::NewSignatureData data;
@@ -456,13 +466,14 @@ private:
     PageView *m_pageView;
 
     bool m_startOver;
+    bool m_aborted;
 };
 
 /** @short PolyLineEngine */
 class PolyLineEngine : public AnnotatorEngine
 {
 public:
-    PolyLineEngine(const QDomElement &engineElement)
+    explicit PolyLineEngine(const QDomElement &engineElement)
         : AnnotatorEngine(engineElement)
         , last(false)
     {
@@ -1051,10 +1062,17 @@ QRect PageViewAnnotator::performRouteMouseOrTabletEvent(const AnnotatorEngine::E
                         KMessageBox::error(m_pageView, i18nc("%1 is a file path", "Could not sign. Invalid certificate password or could not write to '%1'", newFilePath));
                     }
                 }
+                // Exit the signature mode.
+                setSignatureMode(false);
+                selectBuiltinTool(-1, ShowTip::No);
             } else if (signEngine->userWantsToStartOver()) {
                 delete m_engine;
                 m_engine = new PickPointEngineSignature(m_document, m_pageView);
                 return {};
+            } else if (signEngine->isAborted()) {
+                // Exit the signature mode.
+                setSignatureMode(false);
+                selectBuiltinTool(-1, ShowTip::No);
             }
             m_continuousMode = false;
         }
@@ -1167,7 +1185,7 @@ void PageViewAnnotator::selectTool(AnnotationTools *toolsDefinition, int toolId,
         // ask the user for confirmation/change
         if (userName.isEmpty()) {
             bool ok = false;
-            userName = QInputDialog::getText(nullptr, i18n("Bookmark annotation"), i18n("Insert a custom name for the annotation:"), QLineEdit::Normal, QString(), &ok);
+            userName = QInputDialog::getText(nullptr, i18n("Author name"), i18n("Author name for the annotation:"), QLineEdit::Normal, QString(), &ok);
 
             if (!ok) {
                 detachAnnotation();
@@ -1432,7 +1450,7 @@ QPixmap PageViewAnnotator::makeToolPixmap(const QDomElement &toolElement)
         p.drawLine(0, 20, 19, 20);
         p.drawLine(1, 21, 18, 21);
     } else if (annotType == QLatin1String("stamp")) {
-        QPixmap stamp = GuiUtils::loadStamp(icon, 16, false /* keepAspectRatio */);
+        QPixmap stamp = Okular::AnnotationUtils::loadStamp(icon, 16, false /* keepAspectRatio */);
         p.setRenderHint(QPainter::Antialiasing);
         p.drawPixmap(16, 14, stamp);
     } else if (annotType == QLatin1String("straight-line")) {
@@ -1469,6 +1487,12 @@ void PageViewAnnotator::setupActions(KActionCollection *ac)
 {
     if (!m_actionHandler) {
         m_actionHandler = new AnnotationActionHandler(this, ac);
+        connect(m_actionHandler, &AnnotationActionHandler::ephemeralStampWarning, this, [this] {
+            if (m_document->metaData(QStringLiteral("ShowStampsWarning")).toString() == QLatin1String("yes")) {
+                KMessageBox::information(
+                    nullptr, i18nc("@info", "Stamps inserted in PDF documents are not visible in PDF readers other than Okular"), i18nc("@title:window", "Experimental feature"), QStringLiteral("stampAnnotationWarning"));
+            }
+        });
     }
 }
 
